import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from '@nestjs/common';
import {FileFieldsInterceptor} from '@nestjs/platform-express';
import {Constants} from 'src/utils/constants';
import {AdminAuthGuard} from 'src/core/guards/admin-auth.guard';
import {CareerApplicationModelService} from './career-application-model.service';
import {CreateCareerApplicationModelDto} from './dto/create-career-application-model.dto';
import {UpdateCareerApplicationModelDto} from './dto/update-career-application-model.dto';
import {UploadedMulterFileI} from 'src/modules/SpacesModule/SpacesService';

@Controller({path: 'career-application-model', version: Constants.API_VERSION_1})

export class CareerApplicationModelController {
    constructor(private readonly service: CareerApplicationModelService) {
    }

    @Post()
    // @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'resume', maxCount: 1},
        {name: 'coverLetter', maxCount: 1},
    ]))
    create(
        @Body() dto: CreateCareerApplicationModelDto,
        @UploadedFiles() files: {
            resume?: UploadedMulterFileI,
            coverLetter?: UploadedMulterFileI,
        }
    ) {
        return this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'resume', maxCount: 1},
        {name: 'coverLetter', maxCount: 1},
    ]))
    update(
        @Param('id') id: string,
        @Body() dto: UpdateCareerApplicationModelDto,
        @UploadedFiles() files: {
            resume?: UploadedMulterFileI,
            coverLetter?: UploadedMulterFileI,
        }
    ) {
        return this.service.update(id, dto, files);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
