import {Body, Controller, Delete, Get, Param, Patch, Post, UseGuards} from "@nestjs/common";
import {Constants} from "src/utils/constants";
import {AdminAuthGuard} from "src/core/guards/admin-auth.guard";
import {CareerLocationService} from "./career-location.service";
import {CreateCareerLocationDto} from "./dto/create-career-location.dto";
import {UpdateCareerLocationDto} from "./dto/update-career-location.dto";

@Controller({path: "career-location", version: Constants.API_VERSION_1})

export class CareerLocationController {
    constructor(private readonly service: CareerLocationService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateCareerLocationDto) {
        return this.service.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    update(
        @Param("id") id: string,
        @Body() dto: UpdateCareerLocationDto
    ) {
        return this.service.update(id, dto);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
