import {EntityRepository, getConnection, Repository} from "typeorm";
import {CareerTeam} from "./entities/career-team.entity";
import {CreateCareerTeamDto} from "./dto/create-career-team.dto";
import {UpdateCareerTeamDto} from "./dto/update-career-team.dto";

@EntityRepository(CareerTeam)
export class CareerTeamRepository extends Repository<CareerTeam> {
    async createEntity(dto: CreateCareerTeamDto): Promise<CareerTeam | Error> {
        try {
            const {
                name
            } = dto;
            const entity = this.create({
                name
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<CareerTeam | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateCareerTeamDto): Promise<CareerTeam | Error> {
        try {
            await this.update(id, {
                name: dto.name
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<CareerTeam[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(CareerTeam)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}