import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreateFaqContentDto} from "./dto/create-faq-content.dto";
import {UpdateFaqContentDto} from "./dto/update-faq-content.dto";
import {FaqContentEntity} from "./entity/faq-content.entity";

@EntityRepository(FaqContentEntity)
export class FaqContentRepository extends Repository<FaqContentEntity> {

    async createEntity(dto: CreateFaqContentDto): Promise<FaqContentEntity | Error> {
        try {
            const {
                question,
                answer
            } = dto;
            const entity = this.create({
                question,
                answer
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<FaqContentEntity[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<FaqContentEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateFaqContentDto): Promise<FaqContentEntity | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(FaqContentEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}