import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreateHomePageBrandSectionDto} from "./dto/create-home-page-brand-section.dto";
import {UpdateHomePageBrandSectionDto} from "./dto/update-home-page-brand-section.dto";
import {HomePageBrandSectionEntity} from "./entity/home-page-brand-section.entity";

@EntityRepository(HomePageBrandSectionEntity)
export class HomePageBrandSectionRepository extends Repository<HomePageBrandSectionEntity> {

    async createEntity(dto: CreateHomePageBrandSectionDto): Promise<HomePageBrandSectionEntity | Error> {
        try {
            const {
                logo,
                link
            } = dto;
            const entity = this.create({
                logo,
                link
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<HomePageBrandSectionEntity[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<HomePageBrandSectionEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateHomePageBrandSectionDto): Promise<HomePageBrandSectionEntity | Error> {
        try {
            await this.update(id, {
                logo: dto.logo,
                link: dto.link
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(HomePageBrandSectionEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}