import {HttpException, HttpStatus, Injectable} from '@nestjs/common';
import {InjectRepository} from '@nestjs/typeorm';
import {Constants} from 'src/utils/constants';
import {ResponseUtils} from 'src/utils/response.utils';
import {OrganizationSizeRepository} from './organization-size.repository';
import {CreateOrganizationSizeDto} from './dto/create-organization-size.dto';
import {UpdateOrganizationSizeDto} from './dto/update-organization-size.dto';
import {OrganizationSizeEntity} from './entity/organization-size.entity';

@Injectable()
export class OrganizationSizeService {
    constructor(
        @InjectRepository(OrganizationSizeRepository)
        private readonly repository: OrganizationSizeRepository
    ) {
    }

    async create(dto: CreateOrganizationSizeDto): Promise<OrganizationSizeEntity | Error> {
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data Created Successfully", "data", data);
    }

    async findAll(): Promise<OrganizationSizeEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }

    async update(id: string, dto: UpdateOrganizationSizeDto): Promise<OrganizationSizeEntity | Error> {
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Updated Successfully", "data", data);
    }

    async findOne(id: string): Promise<OrganizationSizeEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({id: id});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data Deleted Successfully");
    }
}
