import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreatePressLinkContentDto} from "./dto/create-press-link-content.dto";
import {UpdatePressLinkContentDto} from "./dto/update-press-link-content.dto";
import {PressLinkContentEntity} from "./entity/press-link-content.entity";

@EntityRepository(PressLinkContentEntity)
export class PressLinkContentRepository extends Repository<PressLinkContentEntity> {
    async createEntity(dto: CreatePressLinkContentDto): Promise<PressLinkContentEntity | Error> {
        try {
            const {
                title,
                link,
                icon
            } = dto;
            const entity = this.create({
                title,
                link,
                icon
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<PressLinkContentEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdatePressLinkContentDto): Promise<PressLinkContentEntity | Error> {
        try {
            await this.update(id, {
                title: dto.title,
                link: dto.link,
                icon: dto.icon
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<PressLinkContentEntity[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(PressLinkContentEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}