import {HttpException, HttpStatus, Injectable} from '@nestjs/common';
import {InjectRepository} from '@nestjs/typeorm';
import {Constants} from 'src/utils/constants';
import {ResponseUtils} from 'src/utils/response.utils';
import {PartyRepository} from './party.repository';
import {CreatePartyDto} from './dto/create-party.dto';
import {UpdatePartyDto} from './dto/update-party.dto';
import {PartyEntity} from './entity/party.entity';

@Injectable()
export class PartyService {
    constructor(
        @InjectRepository(PartyRepository)
        private readonly repository: PartyRepository
    ) {
    }

    async create(dto: CreatePartyDto, user: any): Promise<PartyEntity | Error> {
        dto.userId = user.id;
        dto.userName = `${user.firstName} ${user.lastName}`;
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data Created Successfully", "data", data);
    }

    async findAll(user: any): Promise<PartyEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({userId: user.id});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }

    async getAllPartyByUserId(id: string): Promise<any | Error> {
        const data = await this.repository.getAllPartyByUserId(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }

    async update(id: string, dto: UpdatePartyDto, user: any): Promise<PartyEntity | Error> {
        dto.userId = user.id;
        dto.userName = `${user.firstName} ${user.lastName}`;
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Updated Successfully", "data", data);
    }

    async findOne(id: string): Promise<PartyEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({id: id});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data Deleted Successfully");
    }
}
