import {Body, Controller, Delete, Get, Param, Patch, Post, Query, Req, UseGuards} from '@nestjs/common';
import {Constants} from 'src/utils/constants';
import {LogsService} from './logs.service';
import { PaginationDto } from './dto/create-pagination.dto';
import {AuthGuard} from "../../core/guards/auth.guard";
import {CreateLogDto} from './dto/create-log.dto';

@Controller({path: 'logs', version: Constants.API_VERSION_1})
export class LogsController {
    constructor(private readonly service: LogsService) {
    }

    @Post()
    @UseGuards(AuthGuard)
    create(@Body() dto: CreateLogDto, @Req() request: any) {
        return this.service.create(dto, request.user);
    }

    @Get('/all')
    @UseGuards(AuthGuard)
    findAllLogs(@Req() request: any) {
        return this.service.findAllLogs(request.user);
    }

    @Get()
    @UseGuards(AuthGuard)
    findAll(@Req() request: any, @Query() paginationDto: PaginationDto) {
        return this.service.findAll(request.user, paginationDto);
    }

    @Delete(':id')
    @UseGuards(AuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
