import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { PaginationDto } from './dto/create-pagination.dto';
import { CreateLogDto } from './dto/create-log.dto';
import { LogsEntity } from './entity/logs.entity';
import { LogsRepository } from './logs.repository';

@Injectable()
export class LogsService {
    constructor(
        @InjectRepository(LogsRepository)
        private readonly repository: LogsRepository,
    ) {
    }

    async create(dto: CreateLogDto, user: any): Promise<LogsEntity | Error> {
        dto.userId = user.id;
        const data: any = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        } else {
            return ResponseUtils.successResponseHandler(201, "Data Created Successfully", "data", data);
        }
    }


    // async findAll(user: any, paginationDto: PaginationDto): Promise<Partial<LogsEntity[]> | Error> {
    //     const { page, limit } = paginationDto;
    //     const offset = (page - 1) * limit;

    //     const data = await this.repository.findByFilterQuery({ userId: user.id }, offset, limit);

    //     if (!data) {
    //         throw new HttpException(Constants.NOT_FOUND, HttpStatus.NOT_FOUND);
    //     }

    //     const totalCount = await this.repository.count({ userId: user.id });

    //     return ResponseUtils.successResponseHandlerForQueryBuilder(200, "Data Fetched Successfully", "data", data, { page, limit, totalCount });
    // }

    async findAllLogs(user: any): Promise<Partial<LogsEntity[]> | Error> {
        const data = await this.repository.findByFilterLogsQuery({ userId: user.id });
        if (!data) {
            throw new HttpException(Constants.NOT_FOUND, HttpStatus.NOT_FOUND);
        }

        return ResponseUtils.successResponseHandler(
            200,
            'Transaction fetched successfully!',
            'transaction',
            data,
        );
    }

    async findAll(user: any, paginationDto: PaginationDto): Promise<Partial<LogsEntity[]> | Error> {
        const data = await this.repository.findByFilterQuery(user.id, paginationDto);
        if (!data) {
            throw new HttpException(Constants.NOT_FOUND, HttpStatus.NOT_FOUND);
        }

        return ResponseUtils.successResponseHandler(
            200,
            'Transaction fetched successfully!',
            'transaction',
            data,
        );

        // const totalCount = await this.repository.count({ userId: user.id });

        // return ResponseUtils.successResponseHandlerForQueryBuilder(200, "Data Fetched Successfully", "data", data, { page, limit, totalCount });
    }


    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data Deleted Successfully");
    }
}
